import React, { useEffect } from 'react';
import { Form, Select, Input, Button, Space } from 'antd';
import { useProjects } from '../../services/project';
import { useSupplierList } from '../../services/supplier';

interface SearchFormProps {
	project_id: number;
	provider_id: number;
	state: 0 | 1 | -1;
	filter: string;
}
interface Iprops {
	onSearch: (values: SearchFormProps) => void;
}
const deviceState = [
	{
		label: '全部',
		value: -1,
	},
	{
		label: '在线',
		value: 1,
	},
	{
		label: '离线',
		value: 0,
	},
];
const deviceSearch: React.FC<Iprops> = (props) => {
	const { onSearch } = props;
	const [form] = Form.useForm();
	const [projectListState, requestProjectList] = useProjects();
	const [supplierListState, requestSupplierList] = useSupplierList();

	useEffect(() => {
		requestProjectList({
			page: 1,
			page_size: -1,
		});
		requestSupplierList({
			page: 1,
			page_size: -1,
			filter: '',
		});
	}, []);
	const handleSearch = (val) => {};
	return (
		<div>
			<Form layout='inline' onFinish={onSearch} form={form}>
				<Form.Item name='project_id' label='项目名'>
					<Select
						style={{ width: 200 }}
						placeholder='请选择项目'
						allowClear
						filterOption={(input, option) => {
							return (
								option?.children.toLowerCase().indexOf(input.toLowerCase()) >= 0
							);
						}}
						showSearch>
						{projectListState.dataSource.map((project) => {
							return (
								<Select.Option key={project.id} value={project.id}>
									{project.name}
								</Select.Option>
							);
						})}
					</Select>
				</Form.Item>
				<Form.Item name='provider_id' label='供应商'>
					<Select style={{ width: 200 }} placeholder='请选择供应商' allowClear>
						{supplierListState.dataSource.map((project) => {
							return (
								<Select.Option key={project.id} value={project.id}>
									{project.name}
								</Select.Option>
							);
						})}
					</Select>
				</Form.Item>
				<Form.Item name='state' label='状态'>
					<Select style={{ width: 200 }} placeholder='请选择设备状态'>
						{deviceState.map((state) => {
							return (
								<Select.Option key={state.value} value={state.value}>
									{state.label}
								</Select.Option>
							);
						})}
					</Select>
				</Form.Item>
				<Form.Item name='filter' label='关键字'>
					<Input placeholder='设备名' allowClear></Input>
				</Form.Item>
				<Space>
					<Button type='primary' htmlType='submit'>
						搜索
					</Button>
					<Button
						htmlType='reset'
						onClick={() => {
							form.resetFields();
						}}>
						清空
					</Button>
				</Space>
			</Form>
		</div>
	);
};
export default deviceSearch;
