import React, { useEffect } from 'react';
import { Form, Select, Button, Space } from 'antd';
import { useProjects } from '../../services/project';
import { useSupplierList } from '../../services/supplier';
import { useDeviceTypeTotalList } from '../../services/device';
interface SearchFormProps {
	project_id: number;
	provider_id: number;
	state: 0 | 1 | -1;
	filter: string;
}
interface Iprops {
	onSearch: (values: SearchFormProps) => void;
}

const deviceTypeSearch: React.FC<Iprops> = (props) => {
	const { onSearch } = props;
	const [form] = Form.useForm();
	const [projectListState, requestProjectList] = useProjects();
	const {
		state: deviceTypesState,
		request: requestDeviceTypeList,
	} = useDeviceTypeTotalList();
	const [supplierListState, requestSupplierList] = useSupplierList();

	useEffect(() => {
		requestProjectList({
			page: 1,
			page_size: -1,
		});
		requestSupplierList({
			page: 1,
			page_size: -1,
			filter: '',
		});
		requestDeviceTypeList();
	}, []);
	return (
		<div>
			<Form layout='inline' onFinish={onSearch} form={form}>
				<Form.Item name='provider_id' label='供应商'>
					<Select style={{ width: 200 }} placeholder='请选择供应商' allowClear>
						{supplierListState.dataSource.map((project) => {
							return (
								<Select.Option key={project.id} value={project.id}>
									{project.name}
								</Select.Option>
							);
						})}
					</Select>
				</Form.Item>
				<Form.Item name='device_code' label='设备类型'>
					<Select
						allowClear
						style={{ width: 200 }}
						placeholder='请选择设备类型'
						loading={deviceTypesState.loading}>
						{deviceTypesState.dataSource.map((project) => {
							return (
								<Select.Option
									key={project.type_code}
									value={project.type_code}>
									{project.type_name}
								</Select.Option>
							);
						})}
					</Select>
				</Form.Item>
				<Space>
					<Button type='primary' htmlType='submit'>
						搜索
					</Button>
					<Button
						htmlType='reset'
						onClick={() => {
							form.resetFields();
						}}>
						清空
					</Button>
				</Space>
			</Form>
		</div>
	);
};
export default deviceTypeSearch;
