import React, { useState, useEffect } from 'react';
import { PageHeader, Table, Row, Badge, Typography } from 'antd';
import { ColumnProps } from 'antd/lib/table';
import { DeviceSearch } from '../../components/search';
import { useAccessControllerList } from './hook';
const { Text } = Typography;
const DEVICE_STATE = {
	0: '离线',
	1: '在线',
};
const columns: ColumnProps<any>[] = [
	{
		title: '项目名',
		dataIndex: 'project_name',
		key: 'project_name',
	},
	{
		title: '安检备案号',
		dataIndex: 'safety_record_no',
		key: 'safety_record_no',
	},
	{
		title: '供应商',
		dataIndex: 'provider_name',
		key: 'provider_name',
	},
	{
		title: '设备名',
		dataIndex: 'name',
		key: 'name',
	},
	{
		title: '设备唯一编码',
		dataIndex: 'sn',
		key: 'sn',
	},
	{
		title: '设备型号',
		dataIndex: 'model',
		key: 'model',
	},
	{
		title: '生产厂家',
		dataIndex: 'manufacturer',
		key: 'manufacturer',
	},
	{
		title: '状态',
		dataIndex: 'state',
		key: 'state',
		render: (_, record) => {
			const online = record.state === 1;
			return (
				<>
					<Badge status={online ? 'success' : 'error'}></Badge>
					<Text type={online ? 'success' : 'secondary'}>
						{DEVICE_STATE[record.state as 0 | 1]}
					</Text>
				</>
			);
		},
	},
];

const accessController: React.FC = () => {
	const [searchState, changeSearchState] = useState({
		page: 1,
		filter: '',
	});
	const { state: listState, request: requestList } = useAccessControllerList();
	useEffect(() => {
		requestList(searchState);
	}, [searchState]);
	return (
		<>
			<PageHeader title='实名制设备'></PageHeader>
			<DeviceSearch
				onSearch={(data: any) => changeSearchState(data)}></DeviceSearch>
			<Table
				columns={columns}
				dataSource={listState.dataSource}
				pagination={{
					current: listState.page,
					total: listState.total,
					hideOnSinglePage: true,
					onChange: (page) => {
						changeSearchState((preState) => ({ ...preState, page }));
					},
				}}
				loading={listState.loading}></Table>
		</>
	);
};
export default accessController;
