import React, { useEffect } from 'react';
import { RouteComponentProps } from 'react-router-dom';
import { Descriptions, Spin, Button, Divider, Image } from 'antd';
import { useDeviceTypeDetail } from '../../services/device';

const descriptionsListProps = [
	{
		title: '供应商',
		dataIndex: 'provider_name',
	},
	{
		title: '社会统一信用代码',
		dataIndex: 'social_code',
	},
	{
		title: '设备类型',
		dataIndex: 'type_name',
	},
	{
		title: '经办人员',
		dataIndex: 'agent',
	},
	{
		title: '经办人员电话',
		dataIndex: 'agent_phone',
	},
	{
		title: '申请时间',
		dataIndex: 'created_time',
	},
	{
		title: '申请备注',
		dataIndex: 'comment',
	},
	{
		title: '审批人员',
		dataIndex: 'reviewer',
	},
	{
		title: '审批回复',
		dataIndex: 'feedback',
	},
	{
		title: '附件',
		dataIndex: 'appendix',
		render: (data = []) => {
			console.log(data);
			return data.map((element) => {
				return <Image width={100} src={element} key={element}></Image>;
			});
		},
	},
];

const deviceTypeDetail: React.FC<RouteComponentProps<{ id: string }>> = ({
	history,
	match: {
		params: { id },
	},
}) => {
	const { state, request } = useDeviceTypeDetail();
	useEffect(() => {
		request(Number(id));
	}, [id]);
	return (
		<div>
			<Button type='primary' onClick={() => history.goBack()}>
				返回
			</Button>
			<Spin spinning={state.loading}>
				<Descriptions bordered title='入网申请'>
					{descriptionsListProps.map((record) => {
						return (
							<Descriptions.Item label={record.title} key={record.dataIndex}>
								{record.render
									? record.render(
											state.dataSource.add_apply_info[record.dataIndex]
									  )
									: state.dataSource.add_apply_info[record.dataIndex]}
							</Descriptions.Item>
						);
					})}
				</Descriptions>
				<Divider></Divider>
				<Descriptions bordered title='对接测试'>
					{descriptionsListProps.map((record) => {
						return (
							<Descriptions.Item label={record.title} key={record.dataIndex}>
								{record.render
									? record.render(
											state.dataSource.test_apply_info[record.dataIndex]
									  )
									: state.dataSource.test_apply_info[record.dataIndex]}
							</Descriptions.Item>
						);
					})}
				</Descriptions>
			</Spin>
		</div>
	);
};
export default deviceTypeDetail;
