import * as React from 'react';
import { Row, Table, Button, Modal, PageHeader } from 'antd';
import { ColumnProps } from 'antd/lib/table';
import { RouteComponentProps } from 'react-router-dom';
import { DeviceTypeSearch } from '../../components/search';
import { EyeOutlined } from '@ant-design/icons';
import {
	useDeviceTypeList,
	deviceTypeStatus,
	DeviceTypeRecordProps,
} from '../../services/device';
const columns: ColumnProps<DeviceTypeRecordProps>[] = [
	{
		title: '供应商',
		dataIndex: 'provider_name',
		key: 'provider_name',
	},
	{
		title: '社会统一信用代码',
		dataIndex: 'social_code',
		key: 'social_code',
	},
	{
		title: '设备类型',
		dataIndex: 'type_name',
		key: 'type_name',
	},
	{
		title: '经办人员',
		dataIndex: 'agent',
		key: 'agent',
	},
	{
		title: '经办人员电话',
		dataIndex: 'agent_phone',
		key: 'agent_phone',
	},
	{
		title: '申请时间',
		dataIndex: 'created_time',
		key: 'created_time',
	},
	{
		title: '审批时间',
		dataIndex: 'approve_time',
		key: 'approve_time',
	},
];
const accessDevice: React.FC<RouteComponentProps> = ({ history }) => {
	const [searchState, setSearchState] = React.useState<{
		filter: string;
		page: number;
		provider_id?: number;
		list_type: deviceTypeStatus;
	}>({
		filter: '',
		page: 1,
		list_type: 0,
	});
	const [deviceTypeListState, requestAccessDeviceList] = useDeviceTypeList();
	React.useEffect(() => {
		requestAccessDeviceList(searchState);
	}, [JSON.stringify(searchState)]);

	const onSearch = (data) => {
		setSearchState((preState) => ({ ...preState, ...data, page: 1 }));
	};
	const tableCoumns = React.useMemo(() => {
		return columns.concat({
			title: '操作',
			render: (record) => (
				// TODO 查看详情
				<Button
					type='primary'
					onClick={() => {
						history.push(`accessDevices/${record.id}`);
					}}
					icon={<EyeOutlined></EyeOutlined>}>
					详情
				</Button>
			),
		});
	}, []);
	return (
		<div>
			<PageHeader title='入网设备' style={{ paddingLeft: 0 }}></PageHeader>
			<DeviceTypeSearch onSearch={onSearch}></DeviceTypeSearch>

			<Table
				rowKey={(record) => record.id}
				columns={tableCoumns}
				pagination={{
					hideOnSinglePage: true,
					total: deviceTypeListState.total,
					current: deviceTypeListState.page,
					onChange: (page) =>
						setSearchState((preState) => ({ ...preState, page })),
				}}
				loading={deviceTypeListState.loading}
				dataSource={deviceTypeListState.dataSource}></Table>
			<Modal></Modal>
		</div>
	);
};
export default accessDevice;
