import React, { Fragment } from 'react';
import {
	Button,
	Table,
	Modal,
	Row,
	Form,
	Input,
	Descriptions,
	Image,
	PageHeader,
} from 'antd';
import { SearchOutlined, EyeOutlined } from '@ant-design/icons';
import { ColumnProps } from 'antd/lib/table';
import { useCompanyList } from '../../services/company';

const companyExtraInfos = [
	{
		name: '企业名称',
		key: 'name',
	},
	{
		name: '社会统一信用代码',
		key: 'social_code',
	},
	{
		name: '企业地址',
		key: 'addr',
	},
	{
		name: '法定代表人',
		key: 'legal_person',
	},
	{
		name: '法人身份证',
		key: 'id_cert',
	},
	{
		name: '营业执照',
		key: 'business_license',
		img: true,
	},
	{
		name: '业务负责人',
		key: 'business_responsible',
	},
	{
		name: '业务负责人电话',
		key: 'business_responsible_phone',
	},
	{
		name: '紧急联系人',
		key: 'emergency_contact',
	},
	{
		name: '紧急联系人电话',
		key: 'emergency_contact_phone',
	},
	{
		name: '审批时间',
		key: 'approve_time',
	},
	{
		name: '审批回复',
		key: 'feedback',
	},
];

const company: React.FC = () => {
	const [state, setState] = React.useState({
		modalVisible: false,
		detail: {},
	});
	const [searchState, setSearchState] = React.useState({
		page: 1,
		filter: '',
	});
	const [companyListState, requestCompanys] = useCompanyList();
	React.useEffect(() => {
		requestCompanys(searchState);
	}, [searchState]);

	const handleSwitchModalVisible = (detail = {}) => {
		setState((preState) => ({
			...preState,
			modalVisible: !preState.modalVisible,
			detail,
		}));
	};
	const columns: ColumnProps<any>[] = [
		{
			title: '企业名称',
			key: 'name',
			dataIndex: 'name',
		},
		{
			title: '社会统一信用代码',
			key: 'social_code',
			dataIndex: 'social_code',
		},
		{
			title: '业务联系人',
			key: 'business_contact',
			dataIndex: 'business_contact',
		},
		{
			title: '业务联系人电话',
			key: 'business_contact_phone',
			dataIndex: 'business_contact_phone',
		},
		{
			title: '申请时间',
			key: 'apply_time',
			dataIndex: 'apply_time',
		},
		{
			title: '操作',
			render: (record) => {
				return (
					<Button
						type='primary'
						icon={<EyeOutlined></EyeOutlined>}
						onClick={() => handleSwitchModalVisible(record)}>
						详情
					</Button>
				);
			},
		},
	];
	const onSearch = (data) => {
		setSearchState((preState) => ({ ...preState, ...data, page: 1 }));
	};
	return (
		<div>
			<PageHeader title='企业列表' style={{ paddingLeft: 0 }}></PageHeader>
			<div>
				<Form layout='inline' onFinish={onSearch}>
					<Form.Item name='filter'>
						关键字：
						<Input
							style={{ width: 280 }}
							placeholder='企业名称或社会统一信用代码'></Input>
					</Form.Item>
					<Button
						icon={<SearchOutlined></SearchOutlined>}
						type='primary'
						htmlType='submit'>
						搜索
					</Button>
				</Form>
			</div>
			<Table
				rowKey={(record) => record.id}
				columns={columns}
				loading={companyListState.loading}
				pagination={{
					hideOnSinglePage: true,
					total: companyListState.total,
					current: companyListState.page,
					onChange: (page) => {
						setSearchState((preState) => ({ ...preState, page }));
					},
				}}
				dataSource={companyListState.dataSource}></Table>
			{state.detail && Object.keys(state.detail).length > 0 && (
				<Modal
					width={800}
					title='企业详情'
					maskClosable={false}
					onCancel={() => handleSwitchModalVisible()}
					visible={state.modalVisible}
					footer={null}>
					<Descriptions bordered column={{ xxl: 1, xl: 1 }}>
						{companyExtraInfos.map((element) => {
							const currentValue = state.detail[element.key];
							return (
								<Descriptions.Item label={element.name} key={element.key}>
									{element.img
										? currentValue.map((item) => {
												return (
													<Image width={150} height={150} src={item}></Image>
												);
										  })
										: currentValue}
								</Descriptions.Item>
							);
						})}
					</Descriptions>
				</Modal>
			)}
		</div>
	);
};
export default company;
