import { useState } from 'react';
import Request from '../../utils/request';
export const DustState = {
	0: '离线',
	1: '在线',
};
export type DustRecordProps = {
	id: number;
	created_time: string;
	approve_time: string;
	batch: string;
	key: string;
	lat: number;
	lon: number;
	manufacturer: string;
	model: string;
	provider_name: string;
	state: keyof typeof DustState;
};
/**
 * @description 扬尘设备列表
 */
export const useDustList = () => {
	const [state, setState] = useState<{
		loading: boolean;
		dataSource: DustRecordProps[];
		page: number;
		total: number;
	}>({
		loading: false,
		dataSource: [],
		page: 1,
		total: 0,
	});
	const request = (params: { page: number; filter: string }) => {
		setState((preState) => ({
			...preState,
			loading: true,
		}));
		return Request.sendRequest({
			url: '/v1/device/dust_list',
			params,
		})
			.then((data: any) => {
				setState((preState) => ({
					...preState,
					...data,
					loading: false,
					dataSource: data.list,
				}));
			})
			.catch((error) => {
				setState((preState) => ({
					...preState,
					loading: false,
				}));
				return Promise.reject(error);
			});
	};
	return { state, request } as const;
};
