import React, { useEffect } from 'react';
import {
	Row,
	Col,
	Table,
	Form,
	Input,
	Button,
	Typography,
	PageHeader,
	Select,
	Badge,
} from 'antd';
import { ColumnProps } from 'antd/lib/table';
import { useDustList, DustRecordProps, DustState } from './hook';
import { DeviceSearch } from '../../components/search';
import { useDeviceList, deviceStatus, deviceKeys } from '../../services/device';
const { Text } = Typography;

const columns: ColumnProps<DustRecordProps>[] = [
	{
		title: '项目名',
		dataIndex: 'project_name',
		key: 'project_name',
	},
	{
		title: '安检备案号',
		dataIndex: 'safety_record_no',
		key: 'safety_record_no',
	},
	{
		title: '供应商',
		dataIndex: 'provider_name',
		key: 'provider_name',
	},
	{
		title: '设备名',
		dataIndex: 'name',
		key: 'name',
	},
	{
		title: '设备唯一编码',
		dataIndex: 'sn',
		key: 'sn',
	},
	{
		title: '设备型号',
		dataIndex: 'model',
		key: 'model',
	},
	{
		title: '生产厂家',
		dataIndex: 'manufacturer',
		key: 'manufacturer',
	},
	{
		title: '状态',
		dataIndex: 'state',
		key: 'state',
		render: (_, record) => {
			const online = record.state === 1;
			return (
				<>
					<Badge status={online ? 'success' : 'error'}></Badge>
					<Text type={online ? 'success' : 'secondary'}>
						{DustState[record.state as 0 | 1]}
					</Text>
				</>
			);
		},
	},
];

const dust: React.FC = () => {
	const [searchState, setSearchState] = React.useState({
		filter: '',
		page: 1,
	});
	const { state: dustListState, request: requestDustList } = useDustList();

	React.useEffect(() => {
		requestDustList(searchState);
	}, [JSON.stringify(searchState)]);
	const onSearch = (data) => {
		setSearchState((preState) => ({ ...preState, page: 1, ...data }));
	};
	return (
		<div>
			<PageHeader title='扬尘设备' style={{ paddingLeft: 0 }}></PageHeader>
			<DeviceSearch onSearch={onSearch}></DeviceSearch>
			<Table
				rowKey={(record) => record.id}
				columns={columns}
				pagination={{
					showSizeChanger: false,
					hideOnSinglePage: true,
					current: dustListState.page,
					total: dustListState.total,
					onChange: (page) => {
						setSearchState((preState) => ({ ...preState, page }));
					},
				}}
				loading={dustListState.loading}
				dataSource={dustListState.dataSource}></Table>
		</div>
	);
};
export default dust;
