import React, { Fragment } from 'react';
import { Form, Input, Button, Checkbox, message, Typography } from 'antd';
import { Link, RouteComponentProps } from 'react-router-dom';
import JParticles from 'jparticles';

import {
	UserOutlined,
	LockOutlined,
	VerifiedOutlined,
} from '@ant-design/icons';
import { useUserLogin, useCaptchaId } from '../../services/user';
import './index.scss';
const layout = {
	labelCol: { span: 3 },
	wrapperCol: { span: 24 },
};

const login = ({ history }: RouteComponentProps) => {
	const [state, setState] = React.useState({
		timestamp: Date.now(),
	});
	const [loginState, requestLogin] = useUserLogin();
	const [captchState, requestCaptchId] = useCaptchaId();
	const [form] = Form.useForm();
	React.useEffect(() => {
		requestCaptchId();
	}, [state.timestamp]);
	const handleSubmit = (values: any) => {
		if (loginState.loading) {
			return;
		}
		requestLogin({ ...values, captcha: captchState.data.capture_id })
			.then(() => {
				sessionStorage.setItem('username', values.user);
				message.success('登录成功', 1, () => {
					history.replace('/');
				});
			})
			.catch((error) => {
				message.error(error.message);
				setState((preState) => ({ ...preState, timestamp: Date.now() }));
			});
	};
	React.useEffect(() => {
		new JParticles.particle('#login-bg-wrapper', {
			range: 100,
			proximity: 90,
			color: '#A2B0CE',
			parallax: true,
		});
	}, []);
	return (
		<div className='login-wrapper'>
			<div id='login-bg-wrapper'></div>
			<div className='login-content-wrapper'>
				<div className='login-header'>工程管理信息系统</div>
				<div className='login-form-card'>
					<Form
						{...layout}
						form={form}
						initialValues={{ remember: true }}
						onFinish={handleSubmit}
						scrollToFirstError>
						<Form.Item
							name='user'
							colon={false}
							initialValue=''
							rules={[
								{
									required: true,
									message: '请输入用户名!',
								},
							]}>
							<Input
								autoComplete='off'
								prefix={<UserOutlined />}
								placeholder='用户名'
							/>
						</Form.Item>
						<Form.Item
							name='password'
							colon={false}
							initialValue=''
							rules={[
								{
									required: true,
									message: '请输入密码!',
								},
							]}>
							<Input.Password prefix={<LockOutlined />} placeholder='密码' />
						</Form.Item>
						<Form.Item
							name='verify'
							colon={false}
							initialValue=''
							rules={[
								{
									required: true,
									message: '请输入验证码!',
								},
							]}>
							<Input
								autoComplete='off'
								className='login-form-code'
								prefix={<VerifiedOutlined />}
								placeholder='验证码'
								suffix={
									<img
										onClick={() => {
											setState((preState) => ({
												...preState,
												timestamp: Date.now(),
											}));
										}}
										className='capture_img'
										src={`/api/v1/user/captcha_png/${captchState.data.capture_id}`}></img>
								}
							/>
						</Form.Item>
						<Form.Item>
							<Button
								loading={loginState.loading}
								type='primary'
								htmlType='submit'
								block>
								登录
							</Button>
						</Form.Item>
					</Form>
				</div>
			</div>
		</div>
	);
};
export default login;
