import * as React from 'react';
import {
	Row,
	Col,
	Table,
	Form,
	Input,
	Button,
	Modal,
	message,
	Descriptions,
} from 'antd';
import { ColumnProps } from 'antd/lib/table';
import {
	useProjectChangeList,
	ProjectChangeStatus,
	useApplyProject,
} from '../../services/project';
const { TextArea } = Input;

const projectChangeList: React.FC = () => {
	const [form] = Form.useForm();
	const [applyModalState, setApplyModalState] = React.useState<{
		modalVisible: boolean;
		record?: object;
	}>({
		modalVisible: false,
	});
	const [changeInfoModalState, setChangeModalState] = React.useState<{
		modalVisible: boolean;
		record?: object;
	}>({
		modalVisible: false,
	});
	const [searchState, setSearchState] = React.useState({
		filter: '',
		page: 1,
	});

	const [
		projectChangeListState,
		requesProjectChangeList,
	] = useProjectChangeList();
	const onSearch = (data) => {
		setSearchState((preState) => ({ ...preState, ...data, page: 1 }));
	};

	React.useEffect(() => {
		requesProjectChangeList({ page: 1, filter: '' });
	}, [searchState]);
	const [applyState, requestApply] = useApplyProject();

	const handleRequestApply = (data: {
		id: string;
		feedback: string;
		status: boolean;
	}) => {
		if (applyState.loading) {
			return;
		}
		requestApply(data)
			.then(() => {
				requesProjectChangeList(projectChangeListState.deepData);
				handleSwitchApplyModalVisible();
				message.success('审核成功');
			})
			.catch((error) => {
				message.error(error.message);
			});
	};
	const onGetFormData = (data: { status: boolean }) => {
		form.validateFields().then((formData: any) => {
			if (!data.status && !formData['feedback']) {
				return message.error('请输入拒绝原因');
			}
			handleRequestApply({
				...formData,
				...data,
				id: (applyModalState.record as any).id,
			});
		});
	};

	const handleSwitchApplyModalVisible = (record = {}) => {
		setApplyModalState((preState) => ({
			...preState,
			modalVisible: !preState.modalVisible,
			record,
		}));
	};
	const handleSwitchChangeInfoModalVisible = (record = undefined) => {
		setChangeModalState((preState) => ({
			...preState,
			modalVisible: !preState.modalVisible,
			record,
		}));
	};

	const columns: ColumnProps<any>[] = [
		{
			title: '企业名称',
			dataIndex: 'company_name',
			key: 'company_name',
		},
		{
			title: '项目名称',
			dataIndex: 'name',
			key: 'name',
		},
		{
			title: '安监备案号',
			dataIndex: 'safety_record_no',
			key: 'safety_record_no',
		},

		{
			title: '申请时间',
			dataIndex: 'apply_time',
			key: 'apply_time',
		},
		{
			title: '审核状态',
			dataIndex: 'status',
			key: 'status',
			render: (dataIndex) => ProjectChangeStatus[dataIndex],
		},

		{
			title: '操作',
			render: (record) => {
				return (
					<React.Fragment>
						<Button
							style={{ marginRight: 10 }}
							onClick={() => handleSwitchChangeInfoModalVisible(record)}>
							变更信息
						</Button>
						<Button
							disabled={record.status !== 0}
							onClick={() => handleSwitchApplyModalVisible(record)}>
							审核
						</Button>
					</React.Fragment>
				);
			},
		},
	];
	return (
		<div>
			<Row gutter={[0, 30]}>
				<Form layout='inline' onFinish={onSearch}>
					<Form.Item name='filter'>
						<Input
							style={{ width: 280 }}
							placeholder='请输入项目名称或安检备案号'></Input>
					</Form.Item>
					<Button type='primary' htmlType='submit'>
						搜索
					</Button>
				</Form>
			</Row>
			<Table
				columns={columns}
				rowKey={(record) => record.id}
				pagination={{
					hideOnSinglePage: true,
					current: projectChangeListState.page,
					total: projectChangeListState.total,
					onChange: (page) =>
						setSearchState((preState) => ({ ...preState, page })),
				}}
				loading={projectChangeListState.loading}
				dataSource={projectChangeListState.dataSource}></Table>
			<Modal
				visible={applyModalState.modalVisible}
				onCancel={() => handleSwitchApplyModalVisible()}
				maskClosable={false}
				title='审批'
				footer={
					<React.Fragment>
						<Button onClick={() => onGetFormData({ status: true })}>
							通过
						</Button>
						<Button danger onClick={() => onGetFormData({ status: false })}>
							拒绝
						</Button>
					</React.Fragment>
				}>
				<Form form={form}>
					<Form.Item label='回复' name='feedback'>
						<TextArea></TextArea>
					</Form.Item>
				</Form>
			</Modal>
			<Modal
				destroyOnClose
				onCancel={() => handleSwitchChangeInfoModalVisible()}
				maskClosable={false}
				visible={changeInfoModalState.modalVisible}
				title='变更信息'
				footer={null}
				width={800}>
				{changeInfoModalState.record && (
					<Row gutter={[24, 0]}>
						<Col span={12}>
							<Descriptions title='变更前信息' bordered column={{ xxl: 1 }}>
								{(changeInfoModalState as any).record.origin.map((element) => {
									return (
										<Descriptions.Item
											key={element.name}
											label={element.chinese}>
											{element.value}
										</Descriptions.Item>
									);
								})}
							</Descriptions>
						</Col>
						<Col span={12}>
							<Descriptions title='变更后信息' bordered column={{ xxl: 1 }}>
								{(changeInfoModalState as any).record.dst.map((element) => {
									return (
										<Descriptions.Item
											key={element.name}
											label={element.chinese}>
											{element.value}
										</Descriptions.Item>
									);
								})}
							</Descriptions>
							<h3></h3>
						</Col>
					</Row>
				)}
			</Modal>
		</div>
	);
};
export default projectChangeList;
