import React, { useEffect } from 'react';
import { Modal, Descriptions, Spin, message } from 'antd';
import { useProjectDetail } from '../../../../services/project';
import { INVEST_TYPE } from '../../../../contants';
interface ModalDetailProps {
	id?: number;
	visible: boolean;
	onCancle?: () => void;
	onOk?: () => void;
}
const projectExtraInfos = [
	{
		name: '项目名',
		key: 'name',
		span: 1,
	},
	{
		name: '项目类别',
		key: 'category',
		span: 1,
	},
	{
		name: '企业名称',
		key: 'company_name',
		span: 1,
	},
	{
		name: '建设性质',
		key: 'construct_type',
		span: 1,
	},
	{
		name: '建设面积(㎡)',
		key: 'covered_area',
		span: 1,
	},
	{
		name: '创建时间',
		key: 'create_time',
		span: 1,
	},

	{
		name: '计划开工日期',
		key: 'start_day',
		span: 1,
	},
	{
		name: '计划竣工日期',
		key: 'end_day',
		span: 1,
	},

	{
		name: '投资类型',
		key: 'invest_type',
		span: 1,
		render: (data) => {
			return INVEST_TYPE[data];
		},
	},
	{
		name: '工程造价(万)',
		key: 'price',
		span: 1,
	},
	{
		name: '项目状态',
		key: 'project_status',
		span: 1,
	},
	{
		name: '安监备案号',
		key: 'safety_record_no',
		span: 1,
	},
	{
		name: '项目规模',
		key: 'scale',
		span: 1,
	},
	{
		name: '项目经理',
		key: 'project_leader',
		span: 1,
	},
	{
		name: '电话',
		key: 'phone',
		span: 1,
	},
	{
		name: '项目状态',
		key: 'project_status',
		span: 1,
	},
	{
		name: '项目简介',
		key: 'desc',
		span: 2,
	},
	{
		name: '工程地址',
		key: 'location',
		span: 2,
	},
];
const projectFiveUnit = [
	{
		name: '单位名称',
		key: 'name',
		span: 1,
	},
	{
		name: '统一社会信用码',
		key: 'social_code',
		span: 1,
	},
	{
		name: '注册地',
		key: 'area_code',
		span: 1,
	},
	{
		name: '注册时间',
		key: 'register_date',
		span: 1,
	},
];

const ModalDetail: React.FC<ModalDetailProps> = (props) => {
	const { id, visible, onCancle, onOk } = props;
	const { state, request } = useProjectDetail();
	useEffect(() => {
		if (id) {
			request(id).catch((error) => {
				message.error(error.message);
			});
		}
	}, [id]);
	const corp_list = state.dataSource?.corp_list || [];
	return (
		<Modal
			width={1000}
			title='详情'
			onCancel={onCancle}
			onOk={onOk}
			footer={null}
			visible={visible}>
			<Spin spinning={state.loading}>
				<Descriptions bordered title='工程详情' column={{ xxl: 2 }}>
					{projectExtraInfos.map((element) => {
						return (
							<Descriptions.Item
								label={element.name}
								key={element.key}
								span={element.span}>
								{element.render
									? element.render(state.dataSource?.info[element.key])
									: state.dataSource?.info[element.key]}
							</Descriptions.Item>
						);
					})}
				</Descriptions>
				{corp_list.map((unit) => {
					return (
						<Descriptions
							key={unit.id}
							bordered
							title={unit.corp_type}
							column={{ xxl: 2 }}>
							{projectFiveUnit.map((info) => {
								return (
									<Descriptions.Item
										label={info.name}
										key={info.key}
										span={info.span}>
										{unit[info.key] || '-'}
									</Descriptions.Item>
								);
							})}
						</Descriptions>
					);
				})}
			</Spin>
		</Modal>
	);
};
export default ModalDetail;
