import * as React from 'react';
import { Row, PageHeader, Table, Form, Input, Button } from 'antd';
import { EyeOutlined, SearchOutlined } from '@ant-design/icons';
import { ColumnProps } from 'antd/lib/table';
import ModalDetail from './components/modalDetail';
import { useProjects, ProjectRecordProps } from '../../services/project';

const Projects: React.FC = (props) => {
	const [state, setState] = React.useState<{
		modalVisible: boolean;
		detail?: ProjectRecordProps;
	}>({
		modalVisible: false,
	});
	const [searchState, setSearchState] = React.useState({
		filter: '',
		page: 1,
	});

	const [projectListState, requestProjectList] = useProjects();

	const handleSwitchModalVisible = (detail) => {
		setState((preState) => ({
			...preState,
			modalVisible: !preState.modalVisible,
			detail,
		}));
	};
	React.useEffect(() => {
		requestProjectList(searchState);
	}, [searchState]);

	const onSearch = (data) => {
		setSearchState((preState) => ({ ...preState, ...data, page: 1 }));
	};
	const columns: ColumnProps<ProjectRecordProps>[] = [
		{
			title: '项目名',
			dataIndex: 'name',
			key: 'name',
		},
		{
			title: '企业名称',
			dataIndex: 'company_name',
			key: 'company_name',
		},
		{
			title: '项目类型',
			dataIndex: 'category',
			key: 'category',
		},
		{
			title: '项目经理',
			dataIndex: 'manager',
			key: 'manager',
		},
		{
			title: '项目状态',
			dataIndex: 'construct_type',
			key: 'construct_type',
		},
		{
			title: '创建时间',
			dataIndex: 'create_time',
			key: 'create_time',
		},
		{
			title: '项目区域',
			dataIndex: 'location',
			key: 'location',
		},
		{
			title: '操作',
			render: (record) => (
				<Button
					type='primary'
					icon={<EyeOutlined></EyeOutlined>}
					onClick={() => handleSwitchModalVisible(record)}>
					详情
				</Button>
			),
		},
	];
	return (
		<React.Fragment>
			<PageHeader title='工程列表' style={{ paddingLeft: 0 }}></PageHeader>
			<div>
				<Form layout='inline' onFinish={onSearch}>
					<Form.Item name='filter'>
						关键字：
						<Input
							style={{ width: 280 }}
							placeholder='项目名称，安监备案号或工程所在地'></Input>
					</Form.Item>
					<Button
						icon={<SearchOutlined></SearchOutlined>}
						type='primary'
						htmlType='submit'>
						搜索
					</Button>
				</Form>
			</div>
			<Table
				rowKey={(record) => record.id}
				columns={columns}
				pagination={{
					hideOnSinglePage: true,
					total: projectListState.total,
					current: projectListState.page,
					onChange: (page) =>
						setSearchState((preState) => ({ ...preState, page })),
				}}
				dataSource={projectListState.dataSource}></Table>

			<ModalDetail
				onCancle={() => {
					setState((preState) => ({
						...preState,
						modalVisible: false,
						detail: undefined,
					}));
				}}
				visible={state.modalVisible}
				id={state.detail?.id}></ModalDetail>
		</React.Fragment>
	);
};
export default Projects;
