import React from 'react';
import { Form, Modal, Input, Select } from 'antd';
const { TextArea } = Input;
interface Iprops {
	onSubmit: (values: {
		reviewer: string;
		status: boolean;
		feedback?: string;
	}) => void;
	visible: boolean;
	onCancel: () => void;
}
const ReviewPopup: React.FC<Iprops> = ({ visible, onCancel, onSubmit }) => {
	const [form] = Form.useForm();
	const handleSubmit = () => {
		form.validateFields().then((values: any) => {
			console.log('values', values);
			onSubmit({ ...values, status: Boolean(values.status) });
		});
	};
	return (
		<Modal
			title='审批'
			visible={visible}
			onCancel={onCancel}
			onOk={handleSubmit}>
			<Form labelCol={{ span: 4 }} form={form}>
				<Form.Item label='审批人' required name='reviewer'>
					<Input placeholder='请输入审批人' name='name'></Input>
				</Form.Item>
				<Form.Item label='状态' name='status'>
					<Select placeholder='请选择状态'>
						<Select.Option value={1}>通过</Select.Option>
						<Select.Option value={0}>拒绝</Select.Option>
					</Select>
				</Form.Item>
				<Form.Item
					label='原因'
					name='feedback'
					dependencies={['status']}
					rules={[
						({ getFieldValue }) => {
							return {
								validator(_, value) {
									if (!value && getFieldValue('status') === 0) {
										return Promise.reject('请输入拒绝原因');
									}
									return Promise.resolve();
								},
							};
						},
					]}>
					<TextArea placeholder='如果拒绝，需要输入拒绝原因'></TextArea>
				</Form.Item>
			</Form>
		</Modal>
	);
};
export default ReviewPopup;
