import * as React from 'react';
import { Fragment } from 'react';
import {
	Row,
	PageHeader,
	Table,
	Space,
	Button,
	message,
	Badge,
	Typography,
} from 'antd';
import { PushpinOutlined } from '@ant-design/icons';
import { DeviceTypeSearch } from '../../components/search';
import { ColumnProps } from 'antd/lib/table';
import {
	useDeviceTypeList,
	deviceTypeStatus,
	DeviceTypeRecordProps,
	usePutDeviceType,
} from '../../services/device';
import ReviewPopup from './components/reviewPopup';
import DrawerToDetail from './components/detailDrawer';
const { Text } = Typography;

export const deviceTypeApplyStatus = {
	0: '待审核',
	1: '已通过',
	2: '审核退回',
};
const columns: ColumnProps<DeviceTypeRecordProps>[] = [
	{
		title: '设备类型',
		dataIndex: 'type_name',
		key: 'type_name',
	},
	{
		title: '供应商',
		dataIndex: 'provider_name',
		key: 'provider_name',
	},
	{
		title: '统一社会信用代码',
		dataIndex: 'social_code',
		key: 'social_code',
	},
	{
		title: '经办人',
		dataIndex: 'agent',
		key: 'agent',
	},
	{
		title: '经办人电话',
		dataIndex: 'agent_phone',
		key: 'agent_phone',
	},
	{
		title: '备注',
		dataIndex: 'comment',
		key: 'comment',
	},
	{
		title: '申请时间',
		dataIndex: 'created_time',
		key: 'created_time',
	},
];

const drawerDataRows = columns.concat({
	title: '附件',
	dataIndex: 'appendix',
	span: 1,
	img: true,
} as any);
const deviceTypeList: React.FC = () => {
	const [deviceTypeListState, requestDeviceTypeList] = useDeviceTypeList();
	const [reviewModalState, changeReviewModalState] = React.useState<{
		visible: boolean;
		values?: DeviceTypeRecordProps;
	}>({
		visible: false,
		values: undefined,
	});
	const [detailDrawerState, changeDrawerState] = React.useState<{
		visible: boolean;
		values?: DeviceTypeRecordProps;
	}>({
		visible: false,
	});
	const { state: putState, request: requestPutDeviceType } = usePutDeviceType();
	const [searchState, setSearchState] = React.useState<{
		provider_id?: number;
		list_type: deviceTypeStatus;
		page: number;
		filter: string;
	}>({
		list_type: 1,
		page: 1,
		filter: '',
	});

	React.useEffect(() => {
		requestDeviceTypeList(searchState);
	}, [searchState]);

	const onSearch = (data) => {
		setSearchState((preState) => ({ ...preState, ...data, page: 1 }));
	};
	const requestPut = (data) => {
		if (putState.loading) {
			return;
		}
		return requestPutDeviceType({
			...data,
			approveType: 0,
			id: reviewModalState.values?.id,
		})
			.then(() => {
				message.success('审核成功');
				requestDeviceTypeList(searchState);
				changeReviewModalState({ visible: false });
			})
			.catch((error) => {
				message.error(error.message);
				return Promise.reject(error);
			});
	};
	const tableColums = React.useMemo(() => {
		return columns.concat(
			{
				title: '审核状态',
				dataIndex: 'status',
				key: 'status',
				render: (dataIndex, record) => {
					const isRefuse = record.status === 2;
					return (
						<Fragment>
							<Badge status={isRefuse ? 'error' : 'processing'}></Badge>
							<Text type={isRefuse ? 'danger' : 'secondary'}>
								{deviceTypeApplyStatus[dataIndex]}
							</Text>
						</Fragment>
					);
				},
			},
			{
				title: '操作',
				render: (record) => {
					const isRefuse = record.status === 2;
					return (
						<Space>
							<Button
								disabled={isRefuse}
								icon={<PushpinOutlined></PushpinOutlined>}
								onClick={() =>
									changeReviewModalState({ visible: true, values: record })
								}>
								审核
							</Button>
							<Button
								type='primary'
								onClick={() =>
									changeDrawerState({ visible: true, values: record })
								}>
								详情
							</Button>
						</Space>
					);
				},
			}
		);
	}, []);
	return (
		<div>
			<PageHeader
				title='审批-设备类型申请'
				style={{ paddingLeft: 0 }}></PageHeader>
			<DeviceTypeSearch onSearch={onSearch}></DeviceTypeSearch>
			<ReviewPopup
				onSubmit={requestPut}
				onCancel={() => changeReviewModalState({ visible: false })}
				visible={reviewModalState.visible}></ReviewPopup>
			{detailDrawerState.values ? (
				<DrawerToDetail
					dataRows={drawerDataRows}
					values={detailDrawerState.values}
					onSwitchVisible={() => {
						changeDrawerState((preState) => ({
							visible: !preState.visible,
						}));
					}}
					visible={detailDrawerState.visible}></DrawerToDetail>
			) : null}

			<Table
				columns={tableColums}
				rowKey={(record) => record.id}
				pagination={{
					hideOnSinglePage: true,
					current: deviceTypeListState.page,
					total: deviceTypeListState.total,
				}}
				loading={deviceTypeListState.loading}
				dataSource={deviceTypeListState.dataSource}></Table>
		</div>
	);
};
export default deviceTypeList;
