import React, { Fragment } from 'react';
import {
	Row,
	PageHeader,
	Table,
	Form,
	Input,
	Button,
	message,
	Drawer,
	Descriptions,
	Badge,
	Typography,
} from 'antd';
import { ColumnProps } from 'antd/lib/table';
import { SearchOutlined, PushpinOutlined } from '@ant-design/icons';
import {
	useDisassembleList,
	disassembleApplyStatus,
	useApplyDisassemble,
} from '../../services/disassemble';
import ReviewPopup from './components/reviewPopup';
const { Text } = Typography;
const infos = [
	{
		key: 'name',
		name: '设备名',
	},
	{
		key: 'type_name',
		name: '设备类型',
	},
	{
		key: 'sn',
		name: '设备唯一编码',
	},
	{
		name: '供应商',
		key: 'provider_name',
	},
	{
		name: '项目名称',
		key: 'project_name',
	},
	{
		name: '安检备案号',
		key: 'safety_record_no',
	},
	{
		name: '拆机原因',
		key: 'reason',
	},
	{
		name: '申请时间',
		key: 'apply_time',
	},
	{
		name: '审批状态',
		key: 'statusText',
	},
	{
		name: '审批原因',
		key: 'feedback',
	},
	{
		name: '审批时间',
		key: 'approve_time',
	},
];

const deviceTypeList: React.FC = () => {
	const [drawerState, handleChangeDrawerState] = React.useState({
		visible: false,
		values: {},
	});
	const [reviewModalState, changeReviewModalState] = React.useState<{
		visible: boolean;
		values?: any;
	}>({
		visible: false,
	});
	const [searchState, setSearchState] = React.useState({
		filter: '',
		page: 1,
	});

	const [disassembleListState, requestDisassembleList] = useDisassembleList();
	React.useEffect(() => {
		requestDisassembleList(searchState);
	}, [searchState]);
	const onSearch = (data) => {
		setSearchState((preState) => ({ ...preState, ...data, page: 1 }));
	};

	const [applyState, requestApply] = useApplyDisassemble();
	const handleRequestApply = (data) => {
		if (applyState.loading) {
			return;
		}
		requestApply({ ...data, id: reviewModalState.values?.id })
			.then(() => {
				requestDisassembleList(disassembleListState.deepData);
				changeReviewModalState({ visible: false });
				message.success('审核成功');
			})
			.catch((error) => {
				message.error(error.message);
			});
	};

	const columns: ColumnProps<any>[] = [
		{
			title: '设备名',
			dataIndex: 'name',
			key: 'name',
			render: (dataValue, record) => {
				return (
					<a
						onClick={() => {
							handleChangeDrawerState((preState) => ({
								...preState,
								visible: true,
								values: record,
							}));
						}}>
						{dataValue}
					</a>
				);
			},
		},
		{
			title: '设备类型',
			dataIndex: 'type_name',
			key: 'type_name',
		},
		{
			title: '设备唯一编码',
			dataIndex: 'sn',
			key: 'sn',
		},
		{
			title: '供应商',
			dataIndex: 'provider_name',
			key: 'provider_name',
		},
		{
			title: '项目名称',
			dataIndex: 'project_name',
			key: 'project_name',
		},

		{
			title: '拆机原因',
			dataIndex: 'reason',
			key: 'reason',
		},
		{
			title: '申请时间',
			dataIndex: 'apply_time',
			key: 'apply_time',
		},
		{
			title: '审核状态',
			dataIndex: 'status',
			key: 'status',
			render: (dataIndex) => {
				const isrefuse = dataIndex === 2;
				return (
					<Fragment>
						<Badge status={isrefuse ? 'error' : 'processing'}></Badge>
						<Text type={isrefuse ? 'danger' : 'secondary'}>
							{disassembleApplyStatus[dataIndex]}
						</Text>
					</Fragment>
				);
			},
		},
		{
			title: '操作',
			render: (record) => {
				const isRefuse = record.status === 2;
				return isRefuse ? null : (
					<Button
						icon={<PushpinOutlined></PushpinOutlined>}
						onClick={() =>
							changeReviewModalState({ visible: true, values: record })
						}>
						审核
					</Button>
				);
			},
		},
	];
	return (
		<div>
			<PageHeader title='审批-拆机' style={{ paddingLeft: 0 }}></PageHeader>
			<div>
				<Form layout='inline' onFinish={onSearch}>
					<Form.Item name='filter'>
						关键字：
						<Input
							style={{ width: 320 }}
							placeholder='设备唯一编，或项目名称或安监备案号'></Input>
					</Form.Item>
					<Button
						type='primary'
						htmlType='submit'
						icon={<SearchOutlined></SearchOutlined>}>
						搜索
					</Button>
				</Form>
			</div>
			<Table
				columns={columns}
				rowKey={(record) => record.id}
				pagination={{
					hideOnSinglePage: true,
					current: disassembleListState.page,
					total: disassembleListState.total,
					onChange: (page) => {
						setSearchState((preState) => ({ ...preState, page }));
					},
				}}
				loading={disassembleListState.loading}
				dataSource={disassembleListState.dataSource}></Table>
			<ReviewPopup
				onSubmit={handleRequestApply}
				onCancel={() => changeReviewModalState({ visible: false })}
				visible={reviewModalState.visible}></ReviewPopup>
			<Drawer
				width={680}
				title='拆机详情'
				placement='right'
				onClose={() => {
					handleChangeDrawerState((preState) => ({
						...preState,
						visible: false,
					}));
				}}
				visible={drawerState.visible}>
				<Descriptions title={null} column={{ xxl: 1 }} bordered>
					{infos.map((element) => {
						return (
							<Descriptions.Item label={element.name} key={element.key}>
								{drawerState.values[element.key]}
							</Descriptions.Item>
						);
					})}
				</Descriptions>
			</Drawer>
		</div>
	);
};
export default deviceTypeList;
