import React, { useMemo, useEffect } from 'react';
import { Form, Modal, Input, Select, DatePicker } from 'antd';
import { FormItemProps } from 'antd/lib/form';
import { useProjects } from '.././../../../services/project';
import Upload from '../../../../components/upload';
interface Iprops {
	visible: boolean;
	onOk?: (values) => void;
	onCancle: () => void;
}
const createTask: React.FC<Iprops> = ({ visible, onCancle, onOk }) => {
	const [form] = Form.useForm();
	const [projectListState, requestProjectList] = useProjects();
	useEffect(() => {
		requestProjectList({ page_size: -1 });
	}, []);
	const handleSubmit = () => {
		form.validateFields().then((data) => {
			onOk && onOk({ ...data, finish_date: data.finish_date.unix() });
		});
	};
	const formDataProps: FormItemProps[] = useMemo(() => {
		return [
			{
				name: 'task_name',
				label: '任务名称',
				required: true,
				children: <Input placeholder='请输入任务名称'></Input>,
			},

			{
				name: 'project_Id',
				label: '项目',
				required: true,
				children: (
					<Select placeholder='请选择项目'>
						{projectListState.dataSource.map((project) => {
							return (
								<Select.Option key={project.id} value={project.id}>
									{project.name}
								</Select.Option>
							);
						})}
					</Select>
				),
			},
			{
				name: 'finish_date',
				label: '完成日期',
				required: true,
				children: <DatePicker placeholder='请选择任务完成日期'></DatePicker>,
			},
			{
				name: 'task_desc',
				label: '任务描述',
				required: false,
				children: (
					<Input.TextArea placeholder='请填写任务描述'></Input.TextArea>
				),
			},
			{
				name: 'creater',
				label: '创建人',
				required: false,
				children: <Input placeholder='请填写创建人'></Input>,
			},
			{
				name: 'task_img',
				label: '附件',
				required: false,
				children: <Upload></Upload>,
			},
		];
	}, [projectListState.dataSource]);
	return (
		<Modal
			onCancel={onCancle}
			visible={visible}
			title='新建任务'
			onOk={handleSubmit}>
			<Form labelCol={{ span: 4 }} form={form}>
				{formDataProps.map((formItem) => {
					return (
						<Form.Item
							rules={[
								{
									required: formItem.required,
									message: `请输入${formItem.label}`,
								},
							]}
							{...formItem}
							key={formItem.name as string}></Form.Item>
					);
				})}
			</Form>
		</Modal>
	);
};
export default createTask;
