import React, { Fragment, useState, useRef } from 'react';
import { PageHeader, Button, message, Row } from 'antd';
import { RouteComponentProps } from 'react-router-dom';
import Table from './components/table';
import CreateTask from './components/createTask';
import { useAddTask } from './hook';
const warns: React.FC<RouteComponentProps> = ({ history, location }) => {
	const tableListRef = useRef<{ refresh: () => void }>(null);
	const [createModalState, changeCreateModalState] = useState({
		visible: false,
	});
	const { state: addState, request: requestAdd } = useAddTask();
	const submit = (data) => {
		if (addState.loading) {
			return;
		}
		requestAdd({ ...data, task_type: 1 })
			.then(() => {
				message.success('发布任务成功');
				changeCreateModalState({ visible: false });
				tableListRef.current?.refresh();
			})
			.catch((error) => {
				message.error(error.message);
			});
	};
	return (
		<Fragment>
			<PageHeader title='质量列表'></PageHeader>
			<Row justify='end'>
				<Button
					type='primary'
					onClick={() => changeCreateModalState({ visible: true })}>
					创建任务
				</Button>
			</Row>
			<CreateTask
				onOk={submit}
				visible={createModalState.visible}
				onCancle={() => {
					changeCreateModalState({ visible: false });
				}}></CreateTask>
			<Table task_type={1} ref={tableListRef}></Table>
		</Fragment>
	);
};
export default warns;
