import React, { Fragment } from 'react';
import {
	Row,
	Badge,
	Table,
	Form,
	Button,
	Modal,
	Input,
	PageHeader,
	Typography,
} from 'antd';
import { ColumnProps } from 'antd/lib/table';
import { EyeOutlined } from '@ant-design/icons';
import {
	useVideoList,
	useVideoChanels,
	VideoState,
} from '../../services/video';
const { Text } = Typography;
const chanelsTableColumns: ColumnProps<any>[] = [
	{
		title: '通道编号',
		dataIndex: 'channel_no',
		key: 'channel_no',
	},
	{
		title: '名称',
		dataIndex: 'name',
		key: 'name',
	},
	{
		title: '状态',
		dataIndex: 'state',
		key: 'state',
		render: (indexKey) => {
			const online = indexKey === 1;
			return (
				<Fragment>
					<Badge color={online ? 'green' : 'red'}></Badge>
					<Text type={online ? 'success' : 'secondary'}>
						{VideoState[indexKey]}
					</Text>
				</Fragment>
			);
		},
	},
];

const video: React.FC = (props) => {
	const [state, setState] = React.useState<{
		modalVisible: boolean;
		sn?: string;
	}>({
		modalVisible: false,
	});
	const [deviceListState, requestuseVideoList] = useVideoList({ auto: true });
	const [chanelsState, requestChanels] = useVideoChanels();
	/**
	 * @description 查看通道
	 */
	const handleView = React.useCallback((sn?: string) => {
		if (sn) {
			requestChanels({ sn, page: 1 });
		}
		setState((preState) => {
			return {
				...preState,
				modalVisible: !preState.modalVisible,
				sn,
			};
		});
	}, []);
	const columns: ColumnProps<any>[] = [
		{
			title: '项目名',
			dataIndex: 'project_name',
			key: 'project_name',
		},
		{
			title: '安检备案号',
			dataIndex: 'safety_record_no',
			key: 'safety_record_no',
		},
		{
			title: '供应商',
			dataIndex: 'provider_name',
			key: 'provider_name',
		},
		{
			title: '设备名',
			dataIndex: 'name',
			key: 'name',
		},
		{
			title: '国标编号',
			dataIndex: 'sn',
			key: 'sn',
		},
		/*{
			title: '确认状态',
			dataIndex: 'status',
			key: 'status',
			render: (indexKey) => {
				return VideoStatus[indexKey];
			},
		},*/
		{
			title: '状态',
			dataIndex: 'state',
			key: 'state',
			render: (indexKey) => {
				const online = indexKey === 1;
				return (
					<Fragment>
						<Badge color={online ? 'green' : 'red'}></Badge>
						<Text type={online ? 'success' : 'secondary'}>
							{VideoState[indexKey]}
						</Text>
					</Fragment>
				);
			},
		},

		{
			title: '通道',
			render: (record) => {
				return (
					<Button
						type='primary'
						icon={<EyeOutlined></EyeOutlined>}
						disabled={record.status !== 1}
						onClick={() => handleView(record.sn)}>
						查看
					</Button>
				);
			},
		},
	];
	const onSearch = (data) => {
		requestuseVideoList({
			...data,
			page: 1,
		});
	};
	return (
		<div>
			<PageHeader title='视频监控' style={{ paddingLeft: 0 }}></PageHeader>
			<div>
				<Form layout='inline' onFinish={onSearch}>
					<Form.Item name='filter'>
						关键字：
						<Input
							style={{ width: 320 }}
							placeholder='国标编码，项目名称或安监备案号'></Input>
					</Form.Item>
					<Button type='primary' htmlType='submit'>
						搜索
					</Button>
				</Form>
			</div>
			<Table
				rowKey={(record) => record.id}
				columns={columns}
				pagination={{ hideOnSinglePage: true }}
				loading={deviceListState.loading}
				dataSource={deviceListState.dataSource}></Table>
			<Modal
				width={800}
				footer={null}
				maskClosable={false}
				title='通道列表'
				onCancel={() => handleView()}
				visible={state.modalVisible}>
				<Table
					loading={chanelsState.loading}
					rowKey={(record) => record.id}
					dataSource={chanelsState.dataSource}
					pagination={{
						showSizeChanger: false,
						hideOnSinglePage: true,
						total: chanelsState.total,
						current: chanelsState.page,
						onChange: (page) =>
							requestChanels({ ...chanelsState.deepData, page }),
					}}
					columns={chanelsTableColumns}></Table>
			</Modal>
		</div>
	);
};
export default video;
