import * as React from 'react';
import AMapLoader from '@amap/amap-jsapi-loader';
import { message } from 'antd';
import './index.scss';
export type MarkProps = {
	name: string;
	id: number;
	longitude: number;
	latitude: number;
};
interface Iprops {
	list: MarkProps[];
	onMarkClick: (data: MarkProps) => void;
}
let cacheLoadAsync: any[] = [];
let WAMap, myMap;
let isLoading = false;

const loadMap = (callBack: ({ AMap, myMap }) => void) => {
	return new Promise<{ AMap; myMap }>((resolve, reject) => {
		if (isLoading) {
			cacheLoadAsync.push(callBack);
			return;
		}
		if (WAMap && myMap) {
			resolve({ AMap: WAMap, myMap });
			callBack({ AMap: WAMap, myMap });
		} else {
			isLoading = true;

			AMapLoader.load({
				key: 'dcd3ac68361d78c041daf0c652258e3a',
				version: '1.4.15', //不能2.0，IE 下不支持AMap.DistrictLayer
				plugins: [
					'AMap.DistrictSearch',
					'AMap.DistrictLayer',
					'Map3D',
					'AMap.Marker',
				],
			})
				.then((AMap) => {
					WAMap = AMap;
					//获取蒙层
					const disArea = new AMap.DistrictLayer.Province({
						zIndex: 2,
						depth: 2,
						adcode: ['510400'],
						isHotspot: false,
						styles: {
							'city-stroke': '#49AAEA', //中国地级市边界
							fill: function(props) {
								return 'rgba(26,45,105,0.7)';
							},
						},
					});

					myMap = new AMap.Map('visualization-map-container', {
						// zooms: [10, 30],
						center: [101.716007, 26.580446],
						zoom: 8,
						isHotspot: false,
						layers: [disArea],
						viewMode: '2D',
						resizeEnable: true,
					});

					myMap.on('complete', function(status) {
						AMap.plugin(['AMap.DistrictSearch'], function() {
							//标记地图县级以下名称(乡镇)
							const layer = new AMap.LabelsLayer({
								// 开启标注避让，默认为开启，v1.4.15 新增属性
								collision: false,
								// 开启标注淡入动画，默认为开启，v1.4.15 新增属性
								animation: true,
							});
							//搜索地区
							const district = new AMap.DistrictSearch({
								// 关键字对应的行政区级别，country表示国家
								level: 'district',
								//  显示下级行政区级数，1表示返回下一级行政区
								extensions: 'all',
								subdistrict: 2,
							});
							district.search('0812', function(status, result) {
								console.log(result);
								const LabelsData: any[] = [];
								result.districtList[0].districtList.forEach((item) => {
									LabelsData.push({
										name: '',
										position: [
											String(item.center.lng),
											String(item.center.lat),
										],
										zooms: [4, 20],
										zIndex: 5,
										opacity: 1,
										text: {
											content: item.name,
											direction: 'center',
											offset: [0, 0],
											zooms: [3, 20],
											style: {
												fontSize: 10,
												fontWeight: '400',
												fillColor: '#4298D8',
											},
										},
									});
								});
								for (var i = 0; i < LabelsData.length; i++) {
									var labelsMarker = new AMap.LabelMarker(LabelsData[i]);
									layer.add(labelsMarker);
								}
								myMap.add(layer);
							});
						});
					});
					//限制地图展示范围
					const bounds = myMap.getBounds();
					myMap.setLimitBounds(bounds);
					resolve({ AMap, myMap });
					callBack({ AMap, myMap });
					cacheLoadAsync.map((fn) => {
						fn({ AMap: WAMap, myMap });
					});
				})
				.catch((error) => {
					reject(error);
				})
				.finally(() => {
					isLoading = false;
				});
		}
	});
};
const Map: React.FC<Iprops> = React.memo(({ list, onMarkClick }) => {
	React.useEffect(() => {
		loadMap(({ AMap, myMap }) => {}).catch((error) => {
			message.error(error.message);
		});
		return () => {
			cacheLoadAsync = [];
			(WAMap = undefined), (myMap = undefined);
			isLoading = false;
		};
	}, []);
	React.useEffect(() => {
		if (list.length > 0) {
			loadMap(({ AMap, myMap }) => {
				const layer = new AMap.LabelsLayer({
					// 开启标注避让，默认为开启，v1.4.15 新增属性
					collision: false,
					// 开启标注淡入动画，默认为开启，v1.4.15 新增属性
					animation: true,
				});
				for (let i = 0; i < list.length; i++) {
					var labelsMarker = new AMap.LabelMarker({
						position: [list[i].longitude, list[i].latitude],
						zIndex: 99,
						name: list[i].name,
						icon: {
							image: 'https://webapi.amap.com/theme/v1.3/markers/n/mark_b.png',
						},
						text: {
							content: list[i].name,
							style: {
								fontSize: 12,
								fillColor: '#fff',
							},
						},
					});
					labelsMarker.on('click', function() {
						onMarkClick && onMarkClick(list[i]);
					});
					layer.add(labelsMarker);
				}
				myMap.add(layer);
			});
		}
	}, [list]);
	return (
		<div
			id='visualization-map-container'
			style={{ width: '100%', height: '100%' }}></div>
	);
});
export default Map;
