import React, { useState } from 'react';
import { notification } from 'antd';
import Icon, { ArrowUpOutlined, ArrowDownOutlined } from '@ant-design/icons';
import BoxContainer from './components/box-container';
import { RouteComponentProps } from 'react-router-dom';
import Map, { MarkProps } from './components/map';
import EchartsContainer from './components/echrts';
import {
	useDeviceStatistics,
	useDeviceTypeStatistics,
} from '../../services/device';
import { useProjectSum, useProjects } from '../../services/project';
import { useGetTempToken } from '../../services/user';
import { useStaffStatistic } from '../../services/staff';
import deviceStatisticsTotalIcon from './static/device-total-icon.png';
import quarterlyIcon from './static/quarterly-icon.png';
import operationIcon from './static/operation-icon.png';
import abnormalIcon from './static/abnormal-icon.png';
import topOneBg from './static/topOne-bg.png';
import topSecondBg from './static/topSecond-bg.png';
import topThreeBg from './static/topThree-bg.png';

import './index.scss';
const Visualization: React.FC<RouteComponentProps> = ({ history }) => {
	const {
		state: deviceStatisticsState,
		request: requestDeviceStatistics,
	} = useDeviceStatistics();
	const {
		state: getTempTokenState,
		request: requestTempToken,
	} = useGetTempToken();
	const { state: typeState, request: requestTypes } = useDeviceTypeStatistics();
	const { state: staffState, request: requestStaff } = useStaffStatistic();
	const [projectListState, requestProjectList] = useProjects();
	const {
		state: projectSumState,
		request: requestProjectSum,
	} = useProjectSum();
	React.useEffect(() => {
		requestDeviceStatistics();
		requestTypes();
		requestProjectSum();
		requestStaff();
		requestProjectList({ page_size: -1 });
	}, []);
	/**
	 * @description 获取临时token 并跳转到工地得临时登录页面
	 */
	const handleToSite = (data: MarkProps) => {
		requestTempToken({ project_id: String(data.id) })
			.then((data: any) => {
				window.open('http://site.sjzntec.com/tempLogin?token=' + data.token);
			})
			.catch((error) => {
				notification.error({
					message: '获取token错误',
					description: error.message,
				});
			});
	};
	return (
		<div className='visualization-layout'>
			<header className='visualization-header'>
				<div className='app-name'>
					<svg>
						<defs>
							<linearGradient id='grad' x1='50%' y1='0%' x2='50%' y2='100%'>
								<stop
									offset='0%'
									style={{ stopColor: '#04cde7', stopOpacity: 1 }}
								/>
								<stop
									offset='100%'
									style={{ stopColor: '#2b39ed', stopOpacity: 1 }}
								/>
							</linearGradient>
						</defs>
						<text
							x='50%'
							y='50%'
							textAnchor='middle'
							dominantBaseline='middle'
							fill='url(#grad)'
							style={{ fontSize: 32 }}>
							智慧工地
						</text>
					</svg>
				</div>

				<span
					onClick={() => {
						history.push('/admin');
					}}>
					{sessionStorage.getItem('username')}
				</span>
				<span
					className='logout-btn'
					onClick={() => {
						sessionStorage.clear();
						location.href = '/login';
					}}>
					退出
				</span>
			</header>
			<section className='visualization-content'>
				<div className='left-wrapper'>
					<BoxContainer title='设备统计' classname='device-statistics-wrapper'>
						<div className='device-statistics-content'>
							{[
								{
									icon: deviceStatisticsTotalIcon,
									title: '设备总数',
									value: deviceStatisticsState.dataSource.total,
									color: '#00A0FF',
									dataKey: 'total',
								},
								{
									icon: quarterlyIcon,
									title: '季度新增',
									value: deviceStatisticsState.dataSource.increase,
									color: '#1CC894',
									dataKey: 'increase',
								},
								{
									icon: operationIcon,
									title: '运营设备',
									value: deviceStatisticsState.dataSource.online,
									color: '#00CCD6',
									dataKey: 'online',
								},
								{
									icon: abnormalIcon,
									title: '异常设备',
									value: deviceStatisticsState.dataSource.offline,
									color: '#FF5454',
									dataKey: 'offline',
								},
							].map((element) => {
								return (
									<div className='statistics-record' key={element.dataKey}>
										<div
											className='statistics-record-icon'
											style={{
												backgroundImage: `url(${element.icon})`,
											}}></div>
										<span>{element.title}</span>
										<span
											className='statistics-record-value'
											style={{ color: element.color }}>
											{element.value}
										</span>
									</div>
								);
							})}
						</div>
					</BoxContainer>
					<BoxContainer title='设备类型统计' classname='device-type-wrapper'>
						<div className='device-type-content'>
							<div className='device-type-head'>
								<div>设备类型</div>
								<div>总数</div>
								<div>在线</div>
							</div>
							<div className='device-type-body'>
								{typeState.dataSource.map((element) => {
									return (
										<div
											className='device-type-record'
											key={element.device_code}>
											<div>{element.device_type}</div>
											<div>{element.total}</div>
											<div>{element.online}</div>
										</div>
									);
								})}
							</div>
						</div>
					</BoxContainer>
					<BoxContainer
						title='人员新增统计'
						classname='person-increase-wrapper'>
						<div className='person-increase-content'>
							<EchartsContainer
								options={{
									color: ['#00A0FF', '#FF8F00'],
									series: [
										{
											center: ['50%', '50%'],
											left: 0,
											type: 'pie',
											radius: ['22%', '60%'],
											label: {
												show: false,
											},
											labelLine: {
												show: false,
											},
											data: [
												{
													value: staffState.dataSource.total,
													name: '人员总数',
												},
												{
													value: staffState.dataSource.increase,
													name: '本月新增',
												},
											],
										},
									],
								}}></EchartsContainer>
							<div className='person-increase-label'>
								{[
									{
										value: staffState.dataSource.total,
										name: '人员总数',
										color: '#00A0FF',
									},
									{
										value: staffState.dataSource.increase,
										name: '本月新增',
										color: '#FF8F00',
									},
								].map((element) => {
									return (
										<div>
											<span>{element.name}</span>
											<p style={{ color: element.color }}>{element.value}</p>
										</div>
									);
								})}
							</div>
						</div>
					</BoxContainer>
				</div>
				<div className='center-wrapper'>
					<div className='project-sum-wrapper'>
						<div className='project-sum'>
							<p>项目总数</p>
							<span className='project-sum-total'>
								{projectSumState.dataSource.totalText}
							</span>
						</div>
						<div className='project-sum-driver'></div>
						<div className='project-sum'>
							<p>本月新增</p>
							<span>{projectSumState.dataSource.increaseText}</span>
						</div>
					</div>
					<div className='map-conatiner'>
						<Map
							onMarkClick={handleToSite}
							list={projectListState.dataSource.map((element) => {
								return {
									name: element.name,
									id: element.id,
									latitude: element.lat,
									longitude: element.lon,
								};
							})}></Map>
					</div>
					<div className='project-ranking-wrapper'>
						<div className='quality-rectification'>
							<div className='ranking-header'>
								<span>质量整改排行</span>
							</div>
							{[
								{ name: '中铁一局', bg: topOneBg, color: '#FF5353' },
								{ name: '中建一局', bg: topSecondBg, color: '#FF8F00' },
								{ name: '华西集团', bg: topThreeBg, color: '#FFC952' },
							].map((element: any, index) => {
								return (
									<div
										className='ranking-record'
										key={index}
										style={{ backgroundImage: `Url(${element.bg})` }}>
										<span style={{ color: element.color }}>{index + 1}</span>
										<div>{element.name}</div>
									</div>
								);
							})}
						</div>
						<div className='safety-rectification'>
							<div className='ranking-header'>
								<span>安全整改排行</span>
							</div>
							<div className='ranking-body'>
								{[
									{ name: '晋江公寓', value: 23.245, trendUp: true },
									{ name: '晋江公寓', value: 23.245, trendUp: true },
									{ name: '晋江公寓', value: 23.245, trendUp: false },
								].map((element: any, index) => {
									return (
										<div
											className='ranking-record'
											key={index}
											data-arrowup={element.trendUp}>
											<div>
												<span>{element.name}</span>
												<span>{element.value}</span>
											</div>
											{element.trendUp ? (
												<ArrowUpOutlined />
											) : (
												<ArrowDownOutlined />
											)}
										</div>
									);
								})}
							</div>
						</div>
					</div>
				</div>
				<div className='right-wrapper'>
					<BoxContainer title='实时在场统计' classname='real-person-wrapper'>
						<div className='real-person-content'>
							<div className='real-attendace'>
								<span>到场人数</span>
								<div>
									{staffState.dataSource.attendance
										.toLocaleString()
										.split('')
										.map((element, index) => {
											return (
												<div className='attendance-num-block' key={index}>
													{element}
												</div>
											);
										})}
								</div>
							</div>
							<div className='real-total'>
								<p>{staffState.dataSource.total}</p>
								<span>人员总数</span>
							</div>
						</div>
					</BoxContainer>
					<BoxContainer title='项目类型统计' classname='project-type-wrapper'>
						<EchartsContainer
							options={{
								color: ['#1BC793', '#FFC951', '#009FFF', '#FF8F00'],
								title: {
									show: true,
								},
								grid: {
									left: 0,
									bottom: 20,
								},
								legend: {
									show: false,
								},

								series: [
									{
										bottom: 10,
										left: 20,
										type: 'pie',
										roseType: 'area',
										label: {
											show: true,
											position: ['100%', '50%'],
											formatter: '{d|{d}}% \n {b|{b}}',
											align: 'left',
											rich: {
												d: {
													fontFamily: 'lcd',
													fontSize: 12,
													lineHeight: 20,
												},
												b: {
													fontSize: 12,
												},
											},
										},

										labelLine: {
											show: true,
										},
										center: ['50%', '50%'],
										data: projectSumState.dataSource.list.map(
											(element, index) => {
												return {
													name: element.project_type,
													value: element.count,
												};
											}
										),
									},
								],
							}}></EchartsContainer>
					</BoxContainer>
					<div className='examination-wrapper'>
						<div className='quality-examination'>
							<div className='header'>质量检查</div>
						</div>
						<div className='Safety-examination'>
							<div className='header'>安全检查</div>
						</div>
					</div>
					<BoxContainer
						title='企业新增统计'
						classname='companeey-increase-wrapper'>
						<div className='companey-increase-content'>
							<div className='companey-sum-record'>
								<div className='companey-total-process'></div>
								<span>企业总数</span>
								<p>{projectSumState.dataSource.totalText}</p>
							</div>
							<div className='companey-sum-record companey-increase-value'>
								<div className='companey-increase-process'>
									<div
										style={{
											width: projectSumState.dataSource.total
												? (
														(projectSumState.dataSource.increase * 100) /
														projectSumState.dataSource.total
												  ).toFixed(2) + '%'
												: 0,
										}}></div>
								</div>
								<span>本月新增</span>
								<p>{projectSumState.dataSource.increaseText}</p>
							</div>
						</div>
					</BoxContainer>
				</div>
			</section>
		</div>
	);
};
export default Visualization;
