import * as React from 'react';
import {
	Route,
	BrowserRouter as Router,
	Switch,
	Redirect,
} from 'react-router-dom';
import { ConfigProvider } from 'antd';
import zh_CN from 'antd/lib/locale/zh_CN';
import Visualization from '../pages/visualization';
import Login from '../pages/login';
import Layout from '../layout';
import supplierList from '../pages/supplierList';
import deviceTypes from '../pages/review/deviceTypes';
import dustList from '../pages/dust';
import video from '../pages/video';
import accessDevices from '../pages/accessDevice';
import accessDevicesDetail from '../pages/accessDevice/detail';
import accessController from '../pages/accessController';
import enterprise from '../pages/enterprise';
import projects from '../pages/projects';
import supplierApplyList from '../pages/review/supplier';
import companys from '../pages/company';
import companyApplyList from '../pages/review/company';
import disassembleApply from '../pages/review/disassemble';
import projectChangeList from '../pages/projectChangeApply';
import setup from '../pages/setup';
import docking from '../pages/review/docking';

import TaskSafe from '../pages/task/safe';
import TaskQuality from '../pages/task/quality';
import TaskWarns from '../pages/task/warnList';
import TaskDetail from '../pages/task/detail';

const checkLogin = () => {
	return !!sessionStorage.getItem('token');
};
export default () => {
	return (
		<ConfigProvider locale={zh_CN}>
			<Router>
				<Switch>
					<Route
						path='/'
						exact
						render={(props) => {
							return checkLogin() ? (
								<Visualization {...props}></Visualization>
							) : (
								<Redirect to='/login'></Redirect>
							);
						}}></Route>
					<Route path='/login' exact component={Login}></Route>
					<Layout>
						<Switch>
							<Route
								path='/admin'
								exact
								render={() => {
									return <Redirect to='/admin/supplierList'></Redirect>;
								}}></Route>
							<Route path='/admin/setup' component={setup}></Route>

							<Route
								path='/admin/supplierList'
								component={supplierList}></Route>
							<Route path='/admin/dustList' component={dustList}></Route>
							<Route path='/admin/video' component={video}></Route>
							<Route
								path='/admin/accessController'
								component={accessController}></Route>

							<Route
								path='/admin/accessDevices'
								exact
								component={accessDevices}></Route>
							<Route
								path='/admin/accessDevices/:id'
								component={accessDevicesDetail}></Route>
							{/* 建筑企业 */}
							<Route path='/admin/companys' component={companys}></Route>
							<Route path='/admin/projects' component={projects}></Route>

							<Route path='/admin/enterprises' component={enterprise}></Route>
							{/* 审批 */}
							<Route
								path='/admin/supplierApplyList'
								component={supplierApplyList}></Route>
							<Route
								path='/admin/companyApplyList'
								component={companyApplyList}></Route>
							<Route path='/admin/deviceTypes' component={deviceTypes}></Route>
							<Route path='/admin/docking' component={docking}></Route>
							<Route
								path='/admin/disassembleApply'
								component={disassembleApply}></Route>
							<Route
								path='/admin/projectChangeList'
								component={projectChangeList}></Route>
							<Route path='/admin/taskSafe' component={TaskSafe}></Route>
							<Route
								exact
								path='/admin/taskQuality'
								component={TaskQuality}></Route>
							<Route
								exact
								path='/admin/taskWarns'
								component={TaskWarns}></Route>
							<Route
								path='/admin/task/:id'
								exact
								component={TaskDetail}></Route>
						</Switch>
					</Layout>
				</Switch>
			</Router>
		</ConfigProvider>
	);
};
