import { useState } from 'react';
import Request from '../utils/request';
export interface AlarmRecordProps {
  name: string;
  sn: string;
  type_name: string;
  project_name: string;
  safety_record_no: string;
  reason: string;
  time: string;
  id: number;
}
export const useAlarmList = () => {
  const [state, setState] = useState<{
    loading: boolean;
    dataSource: AlarmRecordProps[];
    total: number;
    page: number;
  }>({
    loading: false,
    dataSource: [],
    total: 0,
    page: 1,
  });
  const request = (params: {
    filter: string;
    device_code: number;
    project_id: number;
  }) => {
    setState((preState) => ({ ...preState, loading: true }));
    Request.sendRequest({
      url: '/v1/alarm/list',
      params,
    })
      .then((data: any) => {
        setState((preState) => ({
          ...preState,
          ...data,
          loading: false,
          dataSource: data.list,
        }));
      })
      .catch((error) => {
        setState((preState) => ({
          ...preState,
          loading: false,
        }));
      });
  };
  return { state, request } as const;
};
export const useUpdateAlarm = () => {
  const [state, setState] = useState<{
    loading: boolean;
  }>({
    loading: false,
  });
  const request = async (data: { id: number; handle: boolean }) => {
    setState((preState) => ({ ...preState, loading: true }));
    Request.sendRequest({
      url: '/v1/alarm',
      method: 'PUT',
      data,
    }).finally(() => {
      setState((preState) => ({
        ...preState,
        loading: false,
      }));
    });
  };
  return { state, request } as const;
};
