import * as React from 'react';
import Request from '../utils/request';

export const CompanyApplyStatus = {
  0: '待确认',
  1: '已确认',
  2: '审核退回',
};
/**
 * @description 企业列表
 */
export const useCompanyList = () => {
  const [state, setState] = React.useState({
    loading: false,
    dataSource: [],
    total: 0,
    page: 1,
  });
  const request = (params = { filter: '', page: 1 }) => {
    setState((preState) => ({ ...preState, loading: true }));
    return new Promise((resolve, reject) => {
      Request.sendRequest({
        url: '/v1/company/list',
        params,
      })
        .then((data: any) => {
          setState((preState) => ({
            ...preState,
            loading: false,
            dataSource: data.list.map((element) => {
              return {
                ...element,
                addr: element.province + element.city + element.zone,
                business_license:JSON.parse(element.business_license)
              };
            }),
            total: data.total,
            page: data.page,
          }));
          resolve(data);
        })
        .catch((error) => {
          setState((preState) => ({ ...preState, loading: false }));
          reject(error);
        });
    });
  };

  return [state, request] as const;
};
/**
 * @description 待审批的企业列表
 */
export const useWaitApplyComanyList = () => {
  const [state, setState] = React.useState({
    loading: false,
    dataSource: [],
    deepData: {
      page: 1,
      filter: '',
    },
    total: 0,
    page: 1,
  });
  const request = (params: { filter: string; page: number }) => {
    const newParams = { ...state.deepData, ...params };
    setState((preState) => ({
      ...preState,
      loading: true,
      deepData: newParams,
    }));
    return new Promise((resolve, reject) => {
      Request.sendRequest({
        url: '/v1/company/apply_list',
        params: newParams,
      })
        .then((data: any) => {
          setState((preState) => ({
            ...preState,
            loading: false,
            dataSource: data.list.map((element) => {
              return {
                ...element,
                business_license:JSON.parse(element.business_license),
                addr: element.province + element.city + element.zone,
                statusText: CompanyApplyStatus[element.status],
              };
            }),
            total: data.total,
            page: data.page,
          }));
          resolve(data);
        })
        .catch((error) => {
          setState((preState) => ({ ...preState, loading: false }));
          reject(error);
        });
    });
  };

  return [state, request] as const;
};
/**
 * @description 审核企业
 */
export const useUpdateCompany = () => {
  const [state, setState] = React.useState({ loading: false, dataSource: [] });
  const request = (data: { feedback: string; status: boolean; id: string }) => {
    setState((preState) => ({ ...preState, loading: true }));
    return new Promise((resolve, reject) => {
      Request.sendRequest({
        url: '/v1/company/approve',
        data,
        method: 'PUT',
      })
        .then((data) => {
          resolve(data);
        })
        .catch((error) => {
          reject(error);
        })
        .finally(() => {
          setState((preState) => ({ ...preState, loading: false }));
        });
    });
  };

  return [state, request] as const;
};
