import * as React from 'react';
import Request from '../utils/request';

export const disassembleApplyStatus = {
	0: '待审核',
	1: '审核通过',
	2: '审核退回',
};

/**
 * @description 申请拆机列表
 */
export const useDisassembleList = () => {
	const [state, setState] = React.useState({
		loading: false,
		dataSource: [],
		deepData: {
			page: 1,
			filter: '',
		},
		total: 0,
		page: 1,
	});
	const request = (params: { filter: string; page: number }) => {
		const newParams = { ...state.deepData, ...params };
		setState((preState) => ({
			...preState,
			loading: true,
			deepData: newParams,
		}));
		return Request.sendRequest({
			url: '/v1/device/del_job_list',
			params: newParams,
		})
			.then((data: any) => {
				setState((preState) => ({
					...preState,
					loading: false,
					dataSource: data.list.map((element) => {
						return {
							...element,
							statusText: disassembleApplyStatus[element.status],
						};
					}),
					total: data.total,
					page: data.page,
				}));
			})
			.catch((error) => {
				setState((preState) => ({ ...preState, loading: false }));
			});
	};

	return [state, request] as const;
};
/**
 * @description 审批拆机申请
 */
export const useApplyDisassemble = () => {
	const [state, setState] = React.useState({ loading: false, dataSource: [] });
	const request = (data: { feedback: string; status: boolean; id: string }) => {
		setState((preState) => ({ ...preState, loading: true }));
		return Request.sendRequest({
			url: '/v1/device/del_approve',
			data,
			method: 'PUT',
		}).finally(() => {
			setState((preState) => ({ ...preState, loading: false }));
		});
	};

	return [state, request] as const;
};
