import * as React from 'react';
import Request from '../utils/request';

export type SupplierRecordProps = {
	id: number;
	name: number;
};

export const SupplierApplyStatus = {
	0: '待审核',
	1: '已通过',
	2: '审核退回',
};

/**
 * @description 供应商申请成功得列表
 * @param options
 */
export const useSupplierList = () => {
	const [state, setState] = React.useState<{
		loading: boolean;
		dataSource: SupplierRecordProps[];
		page: number;
		total: number;
		deepDta: any;
	}>({
		loading: false,
		dataSource: [],
		page: 1,
		total: 0,
		deepDta: { page: 1, filter: '' },
	});
	const request = (params: {
		page: number;
		filter: string;
		page_size?: number;
	}) => {
		setState((preState) => ({ ...preState, loading: true }));
		return new Promise((resolve, reject) => {
			Request.sendRequest({
				url: '/v1/provider/list',
				params,
			})
				.then((data: any) => {
					setState((preState) => ({
						...preState,
						loading: false,
						page: data.page,
						total: data.total,
						dataSource: data.list.map((element, index) => {
							return {
								...element,
								business_license: JSON.parse(element.business_license),
								business_responsible_letter: JSON.parse(
									element.business_responsible_letter
								),
								integrity_management_letter: JSON.parse(
									element.integrity_management_letter
								),
								legal_person_letter: JSON.parse(element.legal_person_letter),
							};
						}),
					}));
					resolve(data);
				})
				.catch((error) => {
					setState((preState) => ({ ...preState, loading: false }));
					reject(error);
				});
		});
	};

	return [state, request] as const;
};
/**
 * @description 供应商申请得列表和申请不通过得列表
 */
export const useSupplierApllyList = () => {
	const [state, setState] = React.useState({
		loading: false,
		dataSource: [],
		total: 0,
		page: 1,
		deepData: { page: 1, filter: '' },
	});
	const request = (params: { page: number; filter: string }) => {
		const newDeepData = { ...state.deepData, ...params };
		setState((preState) => ({
			...preState,
			loading: true,
			deepData: newDeepData,
		}));
		return new Promise((resolve, reject) => {
			Request.sendRequest({
				url: '/v1/provider/apply_list',
				params: newDeepData,
			})
				.then((data: any) => {
					setState((preState) => ({
						...preState,
						loading: false,
						...data,
						dataSource: data.list.map(
							({
								business_responsible_letter,
								legal_person_letter,
								business_license,
								integrity_management_letter,
								...rest
							}) => {
								return {
									...rest,
									business_responsible_letter: JSON.parse(
										business_responsible_letter
									),
									legal_person_letter: JSON.parse(legal_person_letter),
									integrity_management_letter: JSON.parse(
										integrity_management_letter
									),
									business_license: JSON.parse(business_license),
									statusText: SupplierApplyStatus[rest.status],
								};
							}
						),
					}));
					resolve(data);
				})
				.catch((error) => {
					setState((preState) => ({ ...preState, loading: false }));
					reject(error);
				});
		});
	};

	return [state, request] as const;
};
/**
 * @description 审核供应商
 */
export const useUpdateSupplier = () => {
	const [state, setState] = React.useState({ loading: false, dataSource: [] });
	const request = (data: { feedback: string; status: boolean; id: string }) => {
		setState((preState) => ({ ...preState, loading: true }));
		return Request.sendRequest({
			url: '/v1/provider/approve',
			data,
			method: 'PUT',
		}).finally(() => {
			setState((preState) => ({ ...preState, loading: false }));
		});
	};
	return [state, request] as const;
};
