import * as React from 'react';
import Request from '../utils/request';
export const VideoStatus = {
	0: '待确认',
	1: '已确认',
	2: '未通过',
};
export const VideoState = {
	0: '离线',
	1: '在线',
};
/**
 * @description 设备类型列表
 */
export const useVideoList = (options = { auto: true }) => {
	const [state, setState] = React.useState({ loading: false, dataSource: [] });
	const request = (params = { filter: '', status_filters: '', page: 1 }) => {
		setState((preState) => ({ ...preState, loading: true }));
		return Request.sendRequest({
			url: '/v1/device/vedio_list',
			params,
		})
			.then((data: any) => {
				setState((preState) => ({
					...preState,
					loading: false,
					...data,
					dataSource: data.list.map((element, index) => {
						return {
							...element,
							index: index + 1,
						};
					}),
				}));
			})
			.catch((error) => {
				setState((preState) => ({ ...preState, loading: false }));
				return Promise.reject(error);
			});
	};
	React.useEffect(() => {
		if (options.auto) {
			request();
		}
	}, []);
	return [state, request] as const;
};
export const chanleState = {
	0: '离线',
	1: '在线',
};

/**
 * @description 视频通道列表
 */
export const useVideoChanels = () => {
	const [state, setState] = React.useState({
		loading: false,
		deepData: {
			sn: '',
			page: 1,
		},
		page: 1,
		total: 0,
		dataSource: [],
	});

	const request = (params: { sn?: string; page: number }) => {
		setState((preState) => ({
			...preState,
			loading: true,
			deepData: { ...preState.deepData, ...params },
		}));
		return Request.sendRequest({
			url: '/v1/device/vedio_channel_list',
			params,
		})
			.then((data: any) => {
				setState((preState) => ({
					...preState,
					dataSource: data.list,
					loading: false,
					total: data.total,
					page: data.page,
				}));
			})
			.catch((error) => {
				setState((preState) => ({ ...preState, loading: false }));
				return Promise.reject(error);
			});
	};
	return [state, request] as const;
};
